# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGBuildingRank(Model):
    """GHGBuildingRank.

    :param place_info:
    :type place_info: ~energycap.sdk.models.PlaceInfo
    :param place_size: The place size
    :type place_size: int
    :param place_size_unit:
    :type place_size_unit: ~energycap.sdk.models.UnitChild
    :param emissions: The overall Greenhouse Gas emissions
    :type emissions: float
    :param scope1_emissions: The Greenhouse Gas emissions from Scope 1
    :type scope1_emissions: float
    :param scope2_emissions: The Greenhouse Gas emissions from Scope 2
    :type scope2_emissions: float
    :param scope3_emissions: The Greenhouse Gas emissions from Scope 3
    :type scope3_emissions: float
    :param emissions_unit:
    :type emissions_unit: ~energycap.sdk.models.UnitChild
    :param intensity: The Greenhouse Gas intensity. Emissions/Place Size
    :type intensity: float
    :param type: The item type
    :type type: str
    :param id: The item identifier
    :type id: int
    :param display: The item display name
    :type display: str
    :param secondary_display: The item formated value
    :type secondary_display: str
    :param value: The item value
    :type value: float
    """

    _attribute_map = {
        'place_info': {'key': 'placeInfo', 'type': 'PlaceInfo'},
        'place_size': {'key': 'placeSize', 'type': 'int'},
        'place_size_unit': {'key': 'placeSizeUnit', 'type': 'UnitChild'},
        'emissions': {'key': 'emissions', 'type': 'float'},
        'scope1_emissions': {'key': 'scope1Emissions', 'type': 'float'},
        'scope2_emissions': {'key': 'scope2Emissions', 'type': 'float'},
        'scope3_emissions': {'key': 'scope3Emissions', 'type': 'float'},
        'emissions_unit': {'key': 'emissionsUnit', 'type': 'UnitChild'},
        'intensity': {'key': 'intensity', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
        'id': {'key': 'id', 'type': 'int'},
        'display': {'key': 'display', 'type': 'str'},
        'secondary_display': {'key': 'secondaryDisplay', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, *, place_info=None, place_size: int=None, place_size_unit=None, emissions: float=None, scope1_emissions: float=None, scope2_emissions: float=None, scope3_emissions: float=None, emissions_unit=None, intensity: float=None, type: str=None, id: int=None, display: str=None, secondary_display: str=None, value: float=None, **kwargs) -> None:
        super(GHGBuildingRank, self).__init__(**kwargs)
        self.place_info = place_info
        self.place_size = place_size
        self.place_size_unit = place_size_unit
        self.emissions = emissions
        self.scope1_emissions = scope1_emissions
        self.scope2_emissions = scope2_emissions
        self.scope3_emissions = scope3_emissions
        self.emissions_unit = emissions_unit
        self.intensity = intensity
        self.type = type
        self.id = id
        self.display = display
        self.secondary_display = secondary_display
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountDigestActualMonthlyResponse(Model):
    """AccountDigestActualMonthlyResponse.

    :param account_code: The account code
    :type account_code: str
    :param account_info: The account info
    :type account_info: str
    :param account_id: The account identifier
    :type account_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of monthly data per commodity
    :type commodities:
     list[~energycap.sdk.models.AccountDigestActualMonthlyResponseCommodityData]
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.AccountDigestActualMonthlyResponseResults]
    """

    _attribute_map = {
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[AccountDigestActualMonthlyResponseCommodityData]'},
        'results': {'key': 'results', 'type': '[AccountDigestActualMonthlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(AccountDigestActualMonthlyResponse, self).__init__(**kwargs)
        self.account_code = kwargs.get('account_code', None)
        self.account_info = kwargs.get('account_info', None)
        self.account_id = kwargs.get('account_id', None)
        self.updated = kwargs.get('updated', None)
        self.global_use_unit = kwargs.get('global_use_unit', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.commodities = kwargs.get('commodities', None)
        self.results = kwargs.get('results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapDashboardSettingsRequest(Model):
    """MapDashboardSettingsRequest.

    All required parameters must be populated in order to send to Azure.

    :param title: Required. The title of the dashboard. <span
     class='property-internal'>Required</span>
    :type title: str
    :param description: The description of the dashboard. <span
     class='property-internal'>Required (defined)</span>
    :type description: str
    :param show_cost: Flag to indicate if Cost data should be shown on the
     dashboard. <span class='property-internal'>Required (defined)</span>
    :type show_cost: bool
    :param show_use: Flag to indicate if Use data should be shown on the
     dashboard. <span class='property-internal'>Required (defined)</span>
    :type show_use: bool
    :param show_ghg: Flag to indicate if Greenhouse Gas data should be shown
     on the dashboard. <span class='property-internal'>Required
     (defined)</span>
    :type show_ghg: bool
    :param map_dashboard_filter: Filters to apply to the map. <span
     class='property-internal'>Required (defined)</span>
    :type map_dashboard_filter: list[~energycap.sdk.models.FilterEdit]
    :param global_commodity_display: Set how commodities should be ordered for
     each data type. Applied individually to Cost, Use, and GHG Emissions.
     Highest - Order displayed commodities in order of Highest Cost/Use/GHG
     Emissions
     Lowest - Order displayed commodities in order Lowest Cost/Use/GHG
     Emissions
     Fixed - Select up to 5 fixed commodities to display. <span
     class='property-internal'>One of Highest, Lowest, Fixed </span> <span
     class='property-internal'>Required (defined)</span>
    :type global_commodity_display: str
    :param fixed_commodity_ids: List of Commodities to display for each data
     type. Required if GlobalCommodityDisplay is Fixed, ignored otherwise.
     Maximum length of 5 items. <span class='property-internal'>Required when
     GlobalCommodityDisplay is set to Fixed</span><span
     class='property-internal'>List cannot be empty</span>
    :type fixed_commodity_ids: list[int]
    """

    _validation = {
        'title': {'required': True, 'max_length': 255},
        'description': {'max_length': 255},
    }

    _attribute_map = {
        'title': {'key': 'title', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'show_cost': {'key': 'showCost', 'type': 'bool'},
        'show_use': {'key': 'showUse', 'type': 'bool'},
        'show_ghg': {'key': 'showGHG', 'type': 'bool'},
        'map_dashboard_filter': {'key': 'mapDashboardFilter', 'type': '[FilterEdit]'},
        'global_commodity_display': {'key': 'globalCommodityDisplay', 'type': 'str'},
        'fixed_commodity_ids': {'key': 'fixedCommodityIds', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(MapDashboardSettingsRequest, self).__init__(**kwargs)
        self.title = kwargs.get('title', None)
        self.description = kwargs.get('description', None)
        self.show_cost = kwargs.get('show_cost', None)
        self.show_use = kwargs.get('show_use', None)
        self.show_ghg = kwargs.get('show_ghg', None)
        self.map_dashboard_filter = kwargs.get('map_dashboard_filter', None)
        self.global_commodity_display = kwargs.get('global_commodity_display', None)
        self.fixed_commodity_ids = kwargs.get('fixed_commodity_ids', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodCostUnitChild(Model):
    """BillingPeriodCostUnitChild.

    :param cost: The total cost.
    :type cost: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'cost': {'key': 'cost', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, *, cost: float=None, unit=None, **kwargs) -> None:
        super(BillingPeriodCostUnitChild, self).__init__(**kwargs)
        self.cost = cost
        self.unit = unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGSettingRequest(Model):
    """GHGSettingRequest.

    All required parameters must be populated in order to send to Azure.

    :param factor_id: Required. The GHG factor to set <span
     class='property-internal'>Required</span>
    :type factor_id: int
    :param scope_category_id: Required. The GHG Scope Category to set <span
     class='property-internal'>Required</span>
    :type scope_category_id: int
    """

    _validation = {
        'factor_id': {'required': True},
        'scope_category_id': {'required': True},
    }

    _attribute_map = {
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'scope_category_id': {'key': 'scopeCategoryId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(GHGSettingRequest, self).__init__(**kwargs)
        self.factor_id = kwargs.get('factor_id', None)
        self.scope_category_id = kwargs.get('scope_category_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalendarizedCalculationRequest(Model):
    """Adding calculation involving meters
    You must pass in at least 1 thing to sum.

    :param sum:
    :type sum: ~energycap.sdk.models.CalendarizedSumRequest
    """

    _attribute_map = {
        'sum': {'key': 'sum', 'type': 'CalendarizedSumRequest'},
    }

    def __init__(self, *, sum=None, **kwargs) -> None:
        super(CalendarizedCalculationRequest, self).__init__(**kwargs)
        self.sum = sum



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectCreate(Model):
    """EnergyProjectCreate.

    All required parameters must be populated in order to send to Azure.

    :param place_id: The place identifier
    :type place_id: int
    :param energy_project_code: Required. The energy project code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type energy_project_code: str
    :param energy_project_info: Required. The energy project info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type energy_project_info: str
    :param installation_begin_date: The energy project installation begin date
    :type installation_begin_date: datetime
    :param installation_end_date: The energy project installation end date
    :type installation_end_date: datetime
    :param installation_cost: The energy project installation cost
    :type installation_cost: float
    :param energy_project_type_code: Required. The energy project type code
     <span class='property-internal'>Required</span>
    :type energy_project_type_code: str
    :param utility_rebate: The rebate amount of energy project
    :type utility_rebate: float
    :param funding_source: The funding source of the project
    :type funding_source: str
    :param project_manager: The project manager of the energy project
    :type project_manager: str
    :param note: The miscellaneous note about the project
    :type note: str
    :param energy_savings: The energy savings amount
    :type energy_savings: float
    :param energy_savings_unit_code: The energy savings unit code
    :type energy_savings_unit_code: str
    :param cost_savings: The cost savings amount
    :type cost_savings: float
    :param cost_savings_unit_code: The cost savings unit code
    :type cost_savings_unit_code: str
    """

    _validation = {
        'energy_project_code': {'required': True, 'max_length': 128, 'min_length': 0},
        'energy_project_info': {'required': True, 'max_length': 128, 'min_length': 0},
        'energy_project_type_code': {'required': True},
    }

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'energy_project_code': {'key': 'energyProjectCode', 'type': 'str'},
        'energy_project_info': {'key': 'energyProjectInfo', 'type': 'str'},
        'installation_begin_date': {'key': 'installationBeginDate', 'type': 'iso-8601'},
        'installation_end_date': {'key': 'installationEndDate', 'type': 'iso-8601'},
        'installation_cost': {'key': 'installationCost', 'type': 'float'},
        'energy_project_type_code': {'key': 'energyProjectTypeCode', 'type': 'str'},
        'utility_rebate': {'key': 'utilityRebate', 'type': 'float'},
        'funding_source': {'key': 'fundingSource', 'type': 'str'},
        'project_manager': {'key': 'projectManager', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'energy_savings': {'key': 'energySavings', 'type': 'float'},
        'energy_savings_unit_code': {'key': 'energySavingsUnitCode', 'type': 'str'},
        'cost_savings': {'key': 'costSavings', 'type': 'float'},
        'cost_savings_unit_code': {'key': 'costSavingsUnitCode', 'type': 'str'},
    }

    def __init__(self, *, energy_project_code: str, energy_project_info: str, energy_project_type_code: str, place_id: int=None, installation_begin_date=None, installation_end_date=None, installation_cost: float=None, utility_rebate: float=None, funding_source: str=None, project_manager: str=None, note: str=None, energy_savings: float=None, energy_savings_unit_code: str=None, cost_savings: float=None, cost_savings_unit_code: str=None, **kwargs) -> None:
        super(EnergyProjectCreate, self).__init__(**kwargs)
        self.place_id = place_id
        self.energy_project_code = energy_project_code
        self.energy_project_info = energy_project_info
        self.installation_begin_date = installation_begin_date
        self.installation_end_date = installation_end_date
        self.installation_cost = installation_cost
        self.energy_project_type_code = energy_project_type_code
        self.utility_rebate = utility_rebate
        self.funding_source = funding_source
        self.project_manager = project_manager
        self.note = note
        self.energy_savings = energy_savings
        self.energy_savings_unit_code = energy_savings_unit_code
        self.cost_savings = cost_savings
        self.cost_savings_unit_code = cost_savings_unit_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandRequest(Model):
    """CalculatedBillDemandRequest.

    :param readings_channel_id: Use channel data readings to calculate bill
     demand <span class='property-internal'>Required (defined)</span>
    :type readings_channel_id: int
    :param fixed_demand:
    :type fixed_demand: ~energycap.sdk.models.FixedDemandRequest
    :param use_wattics_data_point: Use Wattics data readings to calculate bill
     demand <span class='property-internal'>Required (defined)</span>
    :type use_wattics_data_point: bool
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedDemandRequest'},
        'use_wattics_data_point': {'key': 'useWatticsDataPoint', 'type': 'bool'},
    }

    def __init__(self, *, readings_channel_id: int=None, fixed_demand=None, use_wattics_data_point: bool=None, **kwargs) -> None:
        super(CalculatedBillDemandRequest, self).__init__(**kwargs)
        self.readings_channel_id = readings_channel_id
        self.fixed_demand = fixed_demand
        self.use_wattics_data_point = use_wattics_data_point



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class YearRange(Model):
    """General purpose year range DTO.

    :param start_year: The start year for the range
    :type start_year: int
    :param end_year: The end year for the range
    :type end_year: int
    """

    _attribute_map = {
        'start_year': {'key': 'startYear', 'type': 'int'},
        'end_year': {'key': 'endYear', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(YearRange, self).__init__(**kwargs)
        self.start_year = kwargs.get('start_year', None)
        self.end_year = kwargs.get('end_year', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillUseResponse(Model):
    """Definition of how a calculated bill will get its use.

    :param readings_from_channel:
    :type readings_from_channel:
     ~energycap.sdk.models.ChannelChildWithObservationType
    :param fixed_amount:
    :type fixed_amount: ~energycap.sdk.models.FixedAmountResponse
    :param copy_use_from_meter:
    :type copy_use_from_meter: ~energycap.sdk.models.CopyFromMeterResponse
    :param use_calculation:
    :type use_calculation: ~energycap.sdk.models.CalculationResponse
    :param calendarized_use_calculation:
    :type calendarized_use_calculation:
     ~energycap.sdk.models.CalendarizedCalculationResponse
    :param readings_from_wattics_data_point:
    :type readings_from_wattics_data_point:
     ~energycap.sdk.models.WatticsDataPointChild
    """

    _attribute_map = {
        'readings_from_channel': {'key': 'readingsFromChannel', 'type': 'ChannelChildWithObservationType'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'FixedAmountResponse'},
        'copy_use_from_meter': {'key': 'copyUseFromMeter', 'type': 'CopyFromMeterResponse'},
        'use_calculation': {'key': 'useCalculation', 'type': 'CalculationResponse'},
        'calendarized_use_calculation': {'key': 'calendarizedUseCalculation', 'type': 'CalendarizedCalculationResponse'},
        'readings_from_wattics_data_point': {'key': 'readingsFromWatticsDataPoint', 'type': 'WatticsDataPointChild'},
    }

    def __init__(self, **kwargs):
        super(CalculatedBillUseResponse, self).__init__(**kwargs)
        self.readings_from_channel = kwargs.get('readings_from_channel', None)
        self.fixed_amount = kwargs.get('fixed_amount', None)
        self.copy_use_from_meter = kwargs.get('copy_use_from_meter', None)
        self.use_calculation = kwargs.get('use_calculation', None)
        self.calendarized_use_calculation = kwargs.get('calendarized_use_calculation', None)
        self.readings_from_wattics_data_point = kwargs.get('readings_from_wattics_data_point', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardGlobalSettingsEdit(Model):
    """DashboardGlobalSettingsEdit.

    :param show_links: Flag to indicate if public-facing links to the
     application should be displayed <span class='property-internal'>Required
     (defined)</span>
    :type show_links: bool
    :param show_info: Flag to indicate if title/description should be
     displayed <span class='property-internal'>Required (defined)</span>
    :type show_info: bool
    :param global_filter_visibility: Visibility of dashboard filter. Valid
     values are Show, Hide, or Fixed. If settings are applied to a Map
     dashboard, this is automatically set to Fixed, and any other filter
     settings are automatically nulled.
     Show - Filter controls will be show on the dashboard, filter can be
     temporarily set by anybody who can view the dashboard, including public
     viewers.
     Hide - Filter controls will be hidden, manual filtering will be disabled,
     dashboard will be filtered using the topmost place of the user who applies
     the settings
     Fixed - Filter controls will be hidden, dashboard will be filtered using
     the specified Topmost Place or Building Group. PlaceID or PlaceGroupID are
     required when this field is set to Fixed. <span
     class='property-internal'>One of Show, Hide, Fixed </span>
    :type global_filter_visibility: str
    :param place_id: The Identifier for the Topmost Place the dashboard should
     filter by.
     Required when GlobalFilterVisibility is Fixed. Set to null if
     GlobalFilterVisibility is set to Show or Hide.
    :type place_id: int
    :param place_group_id: The Identifier for the Building Group the dashboard
     should filter by.
     Required when GlobalFilterVisibility is Fixed. Set to null if
     GlobalFilterVisibility is set to Show or Hide.
    :type place_group_id: int
    """

    _attribute_map = {
        'show_links': {'key': 'showLinks', 'type': 'bool'},
        'show_info': {'key': 'showInfo', 'type': 'bool'},
        'global_filter_visibility': {'key': 'globalFilterVisibility', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
    }

    def __init__(self, *, show_links: bool=None, show_info: bool=None, global_filter_visibility: str=None, place_id: int=None, place_group_id: int=None, **kwargs) -> None:
        super(DashboardGlobalSettingsEdit, self).__init__(**kwargs)
        self.show_links = show_links
        self.show_info = show_info
        self.global_filter_visibility = global_filter_visibility
        self.place_id = place_id
        self.place_group_id = place_group_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportSubscriptionScheduleTypeResponse(Model):
    """ReportSubscriptionScheduleTypeResponse.

    :param report_subscription_schedule_type_id: The identifier of the
     schedule type
    :type report_subscription_schedule_type_id: int
    :param report_subscription_schedule_type_name: The name of the schedule
     type
    :type report_subscription_schedule_type_name: str
    :param day_indicators: Available day indicators for this schedule type
    :type day_indicators:
     list[~energycap.sdk.models.ReportSubscriptionDayIndicatorChild]
    """

    _attribute_map = {
        'report_subscription_schedule_type_id': {'key': 'reportSubscriptionScheduleTypeId', 'type': 'int'},
        'report_subscription_schedule_type_name': {'key': 'reportSubscriptionScheduleTypeName', 'type': 'str'},
        'day_indicators': {'key': 'dayIndicators', 'type': '[ReportSubscriptionDayIndicatorChild]'},
    }

    def __init__(self, **kwargs):
        super(ReportSubscriptionScheduleTypeResponse, self).__init__(**kwargs)
        self.report_subscription_schedule_type_id = kwargs.get('report_subscription_schedule_type_id', None)
        self.report_subscription_schedule_type_name = kwargs.get('report_subscription_schedule_type_name', None)
        self.day_indicators = kwargs.get('day_indicators', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFSelectValueCreate(Model):
    """UDFSelectValueCreate.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. The UDF select option's value <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type value: str
    :param display_order: Required. The UDF select option's display order
     <span class='property-internal'>Required</span>
    :type display_order: int
    """

    _validation = {
        'value': {'required': True, 'max_length': 255, 'min_length': 0},
        'display_order': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, *, value: str, display_order: int, **kwargs) -> None:
        super(UDFSelectValueCreate, self).__init__(**kwargs)
        self.value = value
        self.display_order = display_order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountingSettingsRequest(Model):
    """AccountingSettingsRequest.

    :param fiscal_year_start_month: First month of fiscal year <span
     class='property-internal'>Must be between 1 and 12</span> <span
     class='property-internal'>Required (defined)</span>
    :type fiscal_year_start_month: int
    :param fiscal_year_defined_at_year: Fiscal year reflects the calendar year
     in which it Begins or Ends <span class='property-internal'>One of
     beginning, ending </span> <span class='property-internal'>Required
     (defined)</span>
    :type fiscal_year_defined_at_year: str
    :param calendarization_method: Calendarization method
     Value will be one of "monthly", "user-defined" <span
     class='property-internal'>One of monthly, user-defined </span> <span
     class='property-internal'>Required (defined)</span>
    :type calendarization_method: str
    :param account_periods: List of accounting period names <span
     class='property-internal'>Required (defined)</span>
    :type account_periods: list[~energycap.sdk.models.AccountPeriodRequest]
    """

    _validation = {
        'fiscal_year_start_month': {'maximum': 12, 'minimum': 1},
    }

    _attribute_map = {
        'fiscal_year_start_month': {'key': 'fiscalYearStartMonth', 'type': 'int'},
        'fiscal_year_defined_at_year': {'key': 'fiscalYearDefinedAtYear', 'type': 'str'},
        'calendarization_method': {'key': 'calendarizationMethod', 'type': 'str'},
        'account_periods': {'key': 'accountPeriods', 'type': '[AccountPeriodRequest]'},
    }

    def __init__(self, *, fiscal_year_start_month: int=None, fiscal_year_defined_at_year: str=None, calendarization_method: str=None, account_periods=None, **kwargs) -> None:
        super(AccountingSettingsRequest, self).__init__(**kwargs)
        self.fiscal_year_start_month = fiscal_year_start_month
        self.fiscal_year_defined_at_year = fiscal_year_defined_at_year
        self.calendarization_method = calendarization_method
        self.account_periods = account_periods



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TrendDataResponse(Model):
    """This DTO is used for the Trend Widget.

    :param target:
    :type target: ~energycap.sdk.models.TrendTarget
    :param period_range:
    :type period_range: ~energycap.sdk.models.PeriodRange
    :param current_year: The latest calendar or fiscal year, denotes the YTD
     year
    :type current_year: int
    :param calendar_type: The type of calendar periods being returned, either
     "Calendar" or "Fiscal".
     This applies to CurrentYear, PeriodRange, and dates in the Values array
    :type calendar_type: str
    :param entities:
    :type entities: list[~energycap.sdk.models.TimeSeriesEntity]
    :param values:
    :type values: list[~energycap.sdk.models.TimeSeriesValue]
    """

    _attribute_map = {
        'target': {'key': 'target', 'type': 'TrendTarget'},
        'period_range': {'key': 'periodRange', 'type': 'PeriodRange'},
        'current_year': {'key': 'currentYear', 'type': 'int'},
        'calendar_type': {'key': 'calendarType', 'type': 'str'},
        'entities': {'key': 'entities', 'type': '[TimeSeriesEntity]'},
        'values': {'key': 'values', 'type': '[TimeSeriesValue]'},
    }

    def __init__(self, *, target=None, period_range=None, current_year: int=None, calendar_type: str=None, entities=None, values=None, **kwargs) -> None:
        super(TrendDataResponse, self).__init__(**kwargs)
        self.target = target
        self.period_range = period_range
        self.current_year = current_year
        self.calendar_type = calendar_type
        self.entities = entities
        self.values = values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilterResponse(Model):
    """FilterResponse.

    :param available_operator: The list of available operators <span
     class='property-internal'>Required (defined)</span>
    :type available_operator: list[str]
    :param caption: The caption of the filter <span
     class='property-internal'>Required (defined)</span>
    :type caption: str
    :param query_parameter_name: The Query parameter name <span
     class='property-internal'>Required (defined)</span>
    :type query_parameter_name: str
    :param field_id: The field identifier <span
     class='property-internal'>Required (defined)</span>
    :type field_id: int
    :param data_field_id: The datafield identifier <span
     class='property-internal'>Required (defined)</span>
    :type data_field_id: int
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    :param operator: The operator <span class='property-internal'>Required
     (defined)</span>
    :type operator: str
    :param value: The value of the filter <span
     class='property-internal'>Required (defined)</span>
    :type value: str
    :param required: Indicates if the filter is required
    :type required: bool
    :param recommended: Indicates if the filter is recommended <span
     class='property-internal'>Required (defined)</span>
    :type recommended: bool
    :param hidden: Indicates if the filter is hidden <span
     class='property-internal'>Required (defined)</span>
    :type hidden: bool
    """

    _attribute_map = {
        'available_operator': {'key': 'availableOperator', 'type': '[str]'},
        'caption': {'key': 'caption', 'type': 'str'},
        'query_parameter_name': {'key': 'queryParameterName', 'type': 'str'},
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'data_field_id': {'key': 'dataFieldId', 'type': 'int'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
        'operator': {'key': 'operator', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'required': {'key': 'required', 'type': 'bool'},
        'recommended': {'key': 'recommended', 'type': 'bool'},
        'hidden': {'key': 'hidden', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(FilterResponse, self).__init__(**kwargs)
        self.available_operator = kwargs.get('available_operator', None)
        self.caption = kwargs.get('caption', None)
        self.query_parameter_name = kwargs.get('query_parameter_name', None)
        self.field_id = kwargs.get('field_id', None)
        self.data_field_id = kwargs.get('data_field_id', None)
        self.data_type = kwargs.get('data_type', None)
        self.operator = kwargs.get('operator', None)
        self.value = kwargs.get('value', None)
        self.required = kwargs.get('required', None)
        self.recommended = kwargs.get('recommended', None)
        self.hidden = kwargs.get('hidden', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListCreateResponse(Model):
    """ListCreateResponse.

    :param list_id: The list identifier.
    :type list_id: int
    :param list_info: The list name.
    :type list_info: str
    :param list_description: The list description.
    :type list_description: str
    :param list_type:
    :type list_type: ~energycap.sdk.models.ListTypeChild
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param shared_list: Is this a list shared with anyone?
    :type shared_list: bool
    :param visible: Is this list visible to me?
    :type visible: bool
    """

    _attribute_map = {
        'list_id': {'key': 'listId', 'type': 'int'},
        'list_info': {'key': 'listInfo', 'type': 'str'},
        'list_description': {'key': 'listDescription', 'type': 'str'},
        'list_type': {'key': 'listType', 'type': 'ListTypeChild'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'shared_list': {'key': 'sharedList', 'type': 'bool'},
        'visible': {'key': 'visible', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ListCreateResponse, self).__init__(**kwargs)
        self.list_id = kwargs.get('list_id', None)
        self.list_info = kwargs.get('list_info', None)
        self.list_description = kwargs.get('list_description', None)
        self.list_type = kwargs.get('list_type', None)
        self.user = kwargs.get('user', None)
        self.shared_list = kwargs.get('shared_list', None)
        self.visible = kwargs.get('visible', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdjustedCostTypeResponse(Model):
    """AdjustedCostTypeResponse.

    :param adjusted_cost_type_id: Adjusted Cost Type identifier
    :type adjusted_cost_type_id: int
    :param adjusted_cost_type_code: Adjusted Cost Type code
    :type adjusted_cost_type_code: str
    :param adjusted_cost_type_info: Adjusted Cost Type name
    :type adjusted_cost_type_info: str
    """

    _attribute_map = {
        'adjusted_cost_type_id': {'key': 'adjustedCostTypeId', 'type': 'int'},
        'adjusted_cost_type_code': {'key': 'adjustedCostTypeCode', 'type': 'str'},
        'adjusted_cost_type_info': {'key': 'adjustedCostTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, adjusted_cost_type_id: int=None, adjusted_cost_type_code: str=None, adjusted_cost_type_info: str=None, **kwargs) -> None:
        super(AdjustedCostTypeResponse, self).__init__(**kwargs)
        self.adjusted_cost_type_id = adjusted_cost_type_id
        self.adjusted_cost_type_code = adjusted_cost_type_code
        self.adjusted_cost_type_info = adjusted_cost_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseRequest(Model):
    """DataAccessReleaseRequest.

    All required parameters must be populated in order to send to Azure.

    :param data_release_file: The response from uploading the file to the file
     store
     API: POST  /api/v202105/fileStore/fileDataType/{fileDataTypeId}/upload
     SDK Operation: UploadFile
    :type data_release_file: str
    :param account_number: Required. Account Number
     Should be a 12 digit number starting with 2. <span
     class='property-internal'>Required</span>
    :type account_number: str
    :param name_on_bill: Required.  <span
     class='property-internal'>Required</span>
    :type name_on_bill: str
    :param service_address: Required.  <span
     class='property-internal'>Required</span>
    :type service_address: str
    """

    _validation = {
        'account_number': {'required': True},
        'name_on_bill': {'required': True},
        'service_address': {'required': True},
    }

    _attribute_map = {
        'data_release_file': {'key': 'dataReleaseFile', 'type': 'str'},
        'account_number': {'key': 'accountNumber', 'type': 'str'},
        'name_on_bill': {'key': 'nameOnBill', 'type': 'str'},
        'service_address': {'key': 'serviceAddress', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataAccessReleaseRequest, self).__init__(**kwargs)
        self.data_release_file = kwargs.get('data_release_file', None)
        self.account_number = kwargs.get('account_number', None)
        self.name_on_bill = kwargs.get('name_on_bill', None)
        self.service_address = kwargs.get('service_address', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetSavingsYearlyResponseCommodityData(Model):
    """WidgetSavingsYearlyResponseCommodityData.

    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param all_time_batcc_use: Program to Date BATCC (Baseline Adjusted to
     Current Conditions) Use
    :type all_time_batcc_use: float
    :param all_time_use: Program to Date Native Use
    :type all_time_use: float
    :param all_time_savings_use: Program to Date Savings Use = allTimeBATCCUse
     - allTimeUse
    :type all_time_savings_use: float
    :param all_time_batcc_total_cost: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Total Cost
    :type all_time_batcc_total_cost: float
    :param all_time_total_cost: Program to Date Total Cost
    :type all_time_total_cost: float
    :param all_time_savings_total_cost: Program to Date Savings Total Cost =
     allTimeBATCCTotalCost - allTimeTotalCost
    :type all_time_savings_total_cost: float
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.WidgetSavingsYearlyResponseResults]
    """

    _attribute_map = {
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'all_time_batcc_use': {'key': 'allTimeBATCCUse', 'type': 'float'},
        'all_time_use': {'key': 'allTimeUse', 'type': 'float'},
        'all_time_savings_use': {'key': 'allTimeSavingsUse', 'type': 'float'},
        'all_time_batcc_total_cost': {'key': 'allTimeBATCCTotalCost', 'type': 'float'},
        'all_time_total_cost': {'key': 'allTimeTotalCost', 'type': 'float'},
        'all_time_savings_total_cost': {'key': 'allTimeSavingsTotalCost', 'type': 'float'},
        'results': {'key': 'results', 'type': '[WidgetSavingsYearlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(WidgetSavingsYearlyResponseCommodityData, self).__init__(**kwargs)
        self.commodity = kwargs.get('commodity', None)
        self.all_time_batcc_use = kwargs.get('all_time_batcc_use', None)
        self.all_time_use = kwargs.get('all_time_use', None)
        self.all_time_savings_use = kwargs.get('all_time_savings_use', None)
        self.all_time_batcc_total_cost = kwargs.get('all_time_batcc_total_cost', None)
        self.all_time_total_cost = kwargs.get('all_time_total_cost', None)
        self.all_time_savings_total_cost = kwargs.get('all_time_savings_total_cost', None)
        self.results = kwargs.get('results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedMonthlyCAPTrendResponse(Model):
    """AggregatedMonthlyCAPTrendResponse.

    :param fiscal_period_range:
    :type fiscal_period_range: ~energycap.sdk.models.PeriodRange
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.MonthlyCAPTrend]
    """

    _attribute_map = {
        'fiscal_period_range': {'key': 'fiscalPeriodRange', 'type': 'PeriodRange'},
        'data_details': {'key': 'dataDetails', 'type': '[MonthlyCAPTrend]'},
    }

    def __init__(self, **kwargs):
        super(AggregatedMonthlyCAPTrendResponse, self).__init__(**kwargs)
        self.fiscal_period_range = kwargs.get('fiscal_period_range', None)
        self.data_details = kwargs.get('data_details', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HiddenRequest(Model):
    """HiddenRequest.

    All required parameters must be populated in order to send to Azure.

    :param hidden: Required. Set a system user role to be hidden or shown
     Roles Manage permission is required to access hidden roles <span
     class='property-internal'>Required</span>
    :type hidden: bool
    """

    _validation = {
        'hidden': {'required': True},
    }

    _attribute_map = {
        'hidden': {'key': 'hidden', 'type': 'bool'},
    }

    def __init__(self, *, hidden: bool, **kwargs) -> None:
        super(HiddenRequest, self).__init__(**kwargs)
        self.hidden = hidden



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionResponse(Model):
    """RateVersionResponse.

    :param version_id: ID of the rate schedule version
    :type version_id: int
    :param begin_date: Begin date for the version
    :type begin_date: datetime
    :param end_date: End date for the version
    :type end_date: datetime
    :param created_date: Created date
    :type created_date: datetime
    :param modified_date: Last modified date
    :type modified_date: datetime
    :param note: Note
    :type note: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param use_unit_cost: Unit cost for the use
    :type use_unit_cost: float
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param demand_unit_cost: Unit cost for the demand
    :type demand_unit_cost: float
    :param demand_unit:
    :type demand_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param account_line_items: Cost bodylines for the account
    :type account_line_items:
     list[~energycap.sdk.models.GenericBodylineResponse]
    :param meter_line_items: Cost bodylines for the meter
    :type meter_line_items:
     list[~energycap.sdk.models.GenericBodylineResponse]
    :param udfs: List of user defined/custom fields and values for this
     version
    :type udfs: list[~energycap.sdk.models.UDFFieldChild]
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'use_unit_cost': {'key': 'useUnitCost', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'demand_unit_cost': {'key': 'demandUnitCost', 'type': 'float'},
        'demand_unit': {'key': 'demandUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'account_line_items': {'key': 'accountLineItems', 'type': '[GenericBodylineResponse]'},
        'meter_line_items': {'key': 'meterLineItems', 'type': '[GenericBodylineResponse]'},
        'udfs': {'key': 'udfs', 'type': '[UDFFieldChild]'},
    }

    def __init__(self, **kwargs):
        super(RateVersionResponse, self).__init__(**kwargs)
        self.version_id = kwargs.get('version_id', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.created_date = kwargs.get('created_date', None)
        self.modified_date = kwargs.get('modified_date', None)
        self.note = kwargs.get('note', None)
        self.created_by = kwargs.get('created_by', None)
        self.modified_by = kwargs.get('modified_by', None)
        self.use_unit_cost = kwargs.get('use_unit_cost', None)
        self.use_unit = kwargs.get('use_unit', None)
        self.demand_unit_cost = kwargs.get('demand_unit_cost', None)
        self.demand_unit = kwargs.get('demand_unit', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.account_line_items = kwargs.get('account_line_items', None)
        self.meter_line_items = kwargs.get('meter_line_items', None)
        self.udfs = kwargs.get('udfs', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGDefaultSettingRequest(Model):
    """GHGDefaultSettingRequest.

    :param commodity_id: The Commodity ID <span
     class='property-internal'>Required (defined)</span>
    :type commodity_id: int
    :param scope_category_id: The Greenhouse Gas Scope category identifier
     <span class='property-internal'>Required (defined)</span>
    :type scope_category_id: int
    :param default_factor:
    :type default_factor: ~energycap.sdk.models.GHGDefaultFactor
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'scope_category_id': {'key': 'scopeCategoryId', 'type': 'int'},
        'default_factor': {'key': 'defaultFactor', 'type': 'GHGDefaultFactor'},
    }

    def __init__(self, *, commodity_id: int=None, scope_category_id: int=None, default_factor=None, **kwargs) -> None:
        super(GHGDefaultSettingRequest, self).__init__(**kwargs)
        self.commodity_id = commodity_id
        self.scope_category_id = scope_category_id
        self.default_factor = default_factor



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactor(Model):
    """GHGFactor.

    :param factor_type: The GHG Factor type.
     Values for this field can be "use meter address" or "specific factor"
    :type factor_type: str
    :param factor_category:
    :type factor_category: ~energycap.sdk.models.GHGFactorCategory
    :param factor_id: The Factor Identifier
    :type factor_id: int
    :param factor_info: The Factor Info
    :type factor_info: str
    :param factor_description: The Factor Description
    :type factor_description: str
    """

    _attribute_map = {
        'factor_type': {'key': 'factorType', 'type': 'str'},
        'factor_category': {'key': 'factorCategory', 'type': 'GHGFactorCategory'},
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'factor_info': {'key': 'factorInfo', 'type': 'str'},
        'factor_description': {'key': 'factorDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGFactor, self).__init__(**kwargs)
        self.factor_type = kwargs.get('factor_type', None)
        self.factor_category = kwargs.get('factor_category', None)
        self.factor_id = kwargs.get('factor_id', None)
        self.factor_info = kwargs.get('factor_info', None)
        self.factor_description = kwargs.get('factor_description', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardGlobalSettings(Model):
    """DashboardGlobalSettings.

    :param show_links: Flag to indicate if public-facing links to the
     application should be displayed
    :type show_links: bool
    :param show_info: Flag to indicate if title/description should be
     displayed
    :type show_info: bool
    :param global_filter_visibility: Visibility of dashboard filter. Values
     are Show, Hide, or Fixed.
     Show - Filter controls are shown on the dashboard, filter can be
     temporarily set by anybody who can view the dashboard, including public
     viewers
     Hide - Filter controls are hidden, filter cannot be set, dashboard will be
     filtered using the topmost place of the user that creates the dashboard
     Fixed - Filter controls are hidden, a fixed filter is applied to the
     dashboard
    :type global_filter_visibility: str
    :param global_filter_type: If GlobalFilterVisibility is Fixed, this is the
     type of filter currently applied to this dashboard. Values are either
     TopmostPlace or BuildingGroup, or blank if GlobalFilterVisibility is not
     Fixed.
     TopmostPlace - Filters the dashboard by a topmost place
     BuildingGroup - Filters the dashboard by a building group
    :type global_filter_type: str
    :param topmost_place:
    :type topmost_place: ~energycap.sdk.models.PlaceChild
    :param building_group:
    :type building_group: ~energycap.sdk.models.PlaceGroupChild
    """

    _attribute_map = {
        'show_links': {'key': 'showLinks', 'type': 'bool'},
        'show_info': {'key': 'showInfo', 'type': 'bool'},
        'global_filter_visibility': {'key': 'globalFilterVisibility', 'type': 'str'},
        'global_filter_type': {'key': 'globalFilterType', 'type': 'str'},
        'topmost_place': {'key': 'topmostPlace', 'type': 'PlaceChild'},
        'building_group': {'key': 'buildingGroup', 'type': 'PlaceGroupChild'},
    }

    def __init__(self, *, show_links: bool=None, show_info: bool=None, global_filter_visibility: str=None, global_filter_type: str=None, topmost_place=None, building_group=None, **kwargs) -> None:
        super(DashboardGlobalSettings, self).__init__(**kwargs)
        self.show_links = show_links
        self.show_info = show_info
        self.global_filter_visibility = global_filter_visibility
        self.global_filter_type = global_filter_type
        self.topmost_place = topmost_place
        self.building_group = building_group



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollingComparisonDetail(Model):
    """RollingComparisonDetail.

    :param year_range:
    :type year_range: ~energycap.sdk.models.YearRange
    :param values: The monthly values within the year range
    :type values: list[~energycap.sdk.models.PeriodValue]
    """

    _attribute_map = {
        'year_range': {'key': 'yearRange', 'type': 'YearRange'},
        'values': {'key': 'values', 'type': '[PeriodValue]'},
    }

    def __init__(self, **kwargs):
        super(RollingComparisonDetail, self).__init__(**kwargs)
        self.year_range = kwargs.get('year_range', None)
        self.values = kwargs.get('values', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodValue(Model):
    """General purpose period value DTO.

    :param period: The period
    :type period: int
    :param value: The value within the period
    :type value: float
    :param formatted_value: The formatted value within the period
    :type formatted_value: str
    """

    _attribute_map = {
        'period': {'key': 'period', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
        'formatted_value': {'key': 'formattedValue', 'type': 'str'},
    }

    def __init__(self, *, period: int=None, value: float=None, formatted_value: str=None, **kwargs) -> None:
        super(PeriodValue, self).__init__(**kwargs)
        self.period = period
        self.value = value
        self.formatted_value = formatted_value
